@@ -3,5 +3,5 @@ from django.conf.urls.defaults import *
 
 urlpatterns = patterns(
     'rewrite_external_links.views',
-    url(r'^external-link/(?P<link>.*)$', 'external_link', name='external_link'),
+    url(r'^external-link/$', 'external_link', name='external_link'),
 )
