@@ -1,12 +1,17 @@
+from django.http import Http404, HttpResponseBadRequest
 from django.template import RequestContext
 from django.shortcuts import render_to_response
 
-def external_link(request, link, extra_context=None):
+def external_link(request, extra_context=None):
 
     context = RequestContext(request)
     if extra_context != None:
         context.update(extra_context)
 
+    link=request.REQUEST.get('link')
+    if not link:
+        return HttpResponseBadRequest('No link passed, or link empty.')
+
     if request.is_ajax():
         template='rewrite_external_links/external_link_ajax.html'
         next=''
